@@ -2,7 +2,9 @@
 # pylint: disable=unused-argument
 
 import os
+import tempfile
 from threading import Thread
+from unittest import mock
 
 import pytest
 from dagster import (
@@ -11,36 +13,33 @@ from dagster import (
     SolidExecutionResult,
     execute_pipeline,
     execute_pipeline_iterator,
-    seven,
 )
 from dagster.core.definitions.reconstructable import ReconstructablePipeline
-from dagster.core.errors import DagsterIncompleteExecutionPlanError, DagsterSubprocessError
+from dagster.core.errors import DagsterExecutionInterruptedError, DagsterSubprocessError
 from dagster.core.events import DagsterEventType
 from dagster.core.test_utils import instance_for_test, instance_for_test_tempdir
 from dagster.utils import send_interrupt
 from dagster_celery_tests.repo import COMPOSITE_DEPTH
+from dagster_celery_tests.utils import start_celery_worker
 
 from .utils import (  # isort:skip
     execute_eagerly_on_celery,
     execute_pipeline_on_celery,
-    skip_ci,
     events_of_type,
     REPO_FILE,
 )
 
 
-@skip_ci
-def test_execute_on_celery(dagster_celery_worker):
+def test_execute_on_celery_default(dagster_celery_worker):
     with execute_pipeline_on_celery("test_pipeline") as result:
         assert result.result_for_solid("simple").output_value() == 1
         assert len(result.step_event_list) == 4
         assert len(events_of_type(result, "STEP_START")) == 1
         assert len(events_of_type(result, "STEP_OUTPUT")) == 1
-        assert len(events_of_type(result, "OBJECT_STORE_OPERATION")) == 1
+        assert len(events_of_type(result, "HANDLED_OUTPUT")) == 1
         assert len(events_of_type(result, "STEP_SUCCESS")) == 1
 
 
-@skip_ci
 def test_execute_serial_on_celery(dagster_celery_worker):
     with execute_pipeline_on_celery("test_serial_pipeline") as result:
         assert result.result_for_solid("simple").output_value() == 1
@@ -49,11 +48,11 @@ def test_execute_serial_on_celery(dagster_celery_worker):
         assert len(events_of_type(result, "STEP_START")) == 2
         assert len(events_of_type(result, "STEP_INPUT")) == 1
         assert len(events_of_type(result, "STEP_OUTPUT")) == 2
-        assert len(events_of_type(result, "OBJECT_STORE_OPERATION")) == 3
+        assert len(events_of_type(result, "HANDLED_OUTPUT")) == 2
+        assert len(events_of_type(result, "LOADED_INPUT")) == 1
         assert len(events_of_type(result, "STEP_SUCCESS")) == 2
 
 
-@skip_ci
 def test_execute_diamond_pipeline_on_celery(dagster_celery_worker):
     with execute_pipeline_on_celery("test_diamond_pipeline") as result:
         assert result.result_for_solid("emit_values").output_values == {
@@ -65,20 +64,11 @@ def test_execute_diamond_pipeline_on_celery(dagster_celery_worker):
         assert result.result_for_solid("subtract").output_value() == -1
 
 
-@skip_ci
 def test_execute_parallel_pipeline_on_celery(dagster_celery_worker):
     with execute_pipeline_on_celery("test_parallel_pipeline") as result:
         assert len(result.solid_result_list) == 11
 
 
-@skip_ci
-@pytest.mark.skip
-def test_execute_more_parallel_pipeline_on_celery():
-    with execute_pipeline_on_celery("test_more_parallel_pipeline") as result:
-        assert len(result.solid_result_list) == 501
-
-
-@skip_ci
 def test_execute_composite_pipeline_on_celery(dagster_celery_worker):
     with execute_pipeline_on_celery("composite_pipeline") as result:
         assert result.success
@@ -103,7 +93,6 @@ def test_execute_composite_pipeline_on_celery(dagster_celery_worker):
         )
 
 
-@skip_ci
 def test_execute_optional_outputs_pipeline_on_celery(dagster_celery_worker):
     with execute_pipeline_on_celery("test_optional_outputs") as result:
         assert len(result.solid_result_list) == 4
@@ -111,63 +100,70 @@ def test_execute_optional_outputs_pipeline_on_celery(dagster_celery_worker):
         assert sum([int(x.success) for x in result.solid_result_list]) == 2
 
 
-@skip_ci
 def test_execute_fails_pipeline_on_celery(dagster_celery_worker):
     with execute_pipeline_on_celery("test_fails") as result:
         assert len(result.solid_result_list) == 2  # fail & skip
         assert not result.result_for_solid("fails").success
         assert (
-            result.result_for_solid("fails").failure_data.error.message == "Exception: argjhgjh\n"
+            "Exception: argjhgjh\n"
+            in result.result_for_solid("fails").failure_data.error.cause.message
         )
         assert result.result_for_solid("should_never_execute").skipped
 
 
-@skip_ci
-# Requires having a dagster-celery worker running locally with --concurrency=1
-def test_terminate_pipeline_on_celery():
-    with seven.TemporaryDirectory() as tempdir:
-        pipeline_def = ReconstructablePipeline.for_file(REPO_FILE, "interrupt_pipeline")
+def test_terminate_pipeline_on_celery(rabbitmq):
+    with start_celery_worker():
+        with tempfile.TemporaryDirectory() as tempdir:
+            pipeline_def = ReconstructablePipeline.for_file(REPO_FILE, "interrupt_pipeline")
 
-        with instance_for_test_tempdir(tempdir) as instance:
-            run_config = {
-                "storage": {"filesystem": {"config": {"base_dir": tempdir}}},
-                "execution": {"celery": {}},
-            }
+            with instance_for_test_tempdir(tempdir) as instance:
+                run_config = {
+                    "intermediate_storage": {"filesystem": {"config": {"base_dir": tempdir}}},
+                    "execution": {"celery": {}},
+                }
 
-            results = []
-            result_types = []
-            interrupt_thread = None
+                results = []
+                result_types = []
+                interrupt_thread = None
+                received_interrupt = False
 
-            try:
-                for result in execute_pipeline_iterator(
-                    pipeline=pipeline_def, run_config=run_config, instance=instance,
-                ):
-                    # Interrupt once the first step starts
-                    if result.event_type == DagsterEventType.STEP_START and not interrupt_thread:
-                        interrupt_thread = Thread(target=send_interrupt, args=())
-                        interrupt_thread.start()
+                try:
+                    for result in execute_pipeline_iterator(
+                        pipeline=pipeline_def,
+                        run_config=run_config,
+                        instance=instance,
+                    ):
+                        # Interrupt once the first step starts
+                        if (
+                            result.event_type == DagsterEventType.STEP_START
+                            and not interrupt_thread
+                        ):
+                            interrupt_thread = Thread(target=send_interrupt, args=())
+                            interrupt_thread.start()
 
-                    results.append(result)
-                    result_types.append(result.event_type)
+                        results.append(result)
+                        result_types.append(result.event_type)
 
-                assert False
-            except DagsterIncompleteExecutionPlanError:
-                pass
+                    assert False
+                except DagsterExecutionInterruptedError:
+                    received_interrupt = True
 
-            interrupt_thread.join()
+                interrupt_thread.join()
 
-            # At least one step succeeded (the one that was running when the interrupt fired)
-            assert DagsterEventType.STEP_SUCCESS in result_types
+                assert received_interrupt
 
-            # At least one step was revoked (and there were no step failure events)
-            revoke_steps = [
-                result
-                for result in results
-                if result.event_type == DagsterEventType.ENGINE_EVENT
-                and "was revoked." in result.message
-            ]
+                # At least one step succeeded (the one that was running when the interrupt fired)
+                assert DagsterEventType.STEP_SUCCESS in result_types
 
-            assert len(revoke_steps) > 0
+                # At least one step was revoked (and there were no step failure events)
+                revoke_steps = [
+                    result
+                    for result in results
+                    if result.event_type == DagsterEventType.ENGINE_EVENT
+                    and "was revoked." in result.message
+                ]
+
+                assert len(revoke_steps) > 0
 
             # The overall pipeline failed
             assert DagsterEventType.PIPELINE_FAILURE in result_types
@@ -180,7 +176,7 @@ def test_execute_eagerly_on_celery():
             assert len(result.step_event_list) == 4
             assert len(events_of_type(result, "STEP_START")) == 1
             assert len(events_of_type(result, "STEP_OUTPUT")) == 1
-            assert len(events_of_type(result, "OBJECT_STORE_OPERATION")) == 1
+            assert len(events_of_type(result, "HANDLED_OUTPUT")) == 1
             assert len(events_of_type(result, "STEP_SUCCESS")) == 1
 
             events = instance.all_logs(result.run_id)
@@ -188,7 +184,7 @@ def test_execute_eagerly_on_celery():
             end_markers = {}
             for event in events:
                 dagster_event = event.dagster_event
-                if dagster_event.is_engine_event:
+                if dagster_event and dagster_event.is_engine_event:
                     if dagster_event.engine_event_data.marker_start:
                         key = "{step}.{marker}".format(
                             step=event.step_key, marker=dagster_event.engine_event_data.marker_start
@@ -215,7 +211,8 @@ def test_execute_eagerly_serial_on_celery():
         assert len(events_of_type(result, "STEP_START")) == 2
         assert len(events_of_type(result, "STEP_INPUT")) == 1
         assert len(events_of_type(result, "STEP_OUTPUT")) == 2
-        assert len(events_of_type(result, "OBJECT_STORE_OPERATION")) == 3
+        assert len(events_of_type(result, "HANDLED_OUTPUT")) == 2
+        assert len(events_of_type(result, "LOADED_INPUT")) == 1
         assert len(events_of_type(result, "STEP_SUCCESS")) == 2
 
 
@@ -244,12 +241,6 @@ def test_execute_eagerly_parallel_pipeline_on_celery():
         assert len(result.solid_result_list) == 11
 
 
-@pytest.mark.skip
-def test_execute_eagerly_more_parallel_pipeline_on_celery():
-    with execute_eagerly_on_celery("test_more_parallel_pipeline") as result:
-        assert len(result.solid_result_list) == 501
-
-
 def test_execute_eagerly_composite_pipeline_on_celery():
     with execute_eagerly_on_celery("composite_pipeline") as result:
         assert result.success
@@ -292,7 +283,8 @@ def test_execute_eagerly_fails_pipeline_on_celery():
         assert len(result.solid_result_list) == 2
         assert not result.result_for_solid("fails").success
         assert (
-            result.result_for_solid("fails").failure_data.error.message == "Exception: argjhgjh\n"
+            "Exception: argjhgjh\n"
+            in result.result_for_solid("fails").failure_data.error.cause.message
         )
         assert result.result_for_solid("should_never_execute").skipped
 
@@ -305,38 +297,25 @@ def test_execute_eagerly_retries_pipeline_on_celery():
         assert len(events_of_type(result, "STEP_FAILURE")) == 1
 
 
-@pytest.mark.skip("https://github.com/dagster-io/dagster/issues/2439")
-def test_bad_broker():
-    pass
-    # with pytest.raises(check.CheckError) as exc_info:
-    #     with instance_for_test() as instance:
-    #         event_stream = execute_pipeline_iterator(
-    #             ExecutionTargetHandle.for_pipeline_python_file(
-    #                 __file__, "test_diamond_pipeline"
-    #             ).build_pipeline_definition(),
-    #             run_config={
-    #                 "storage": {"filesystem": {}},
-    #                 "execution": {"celery": {"config": {"broker": "notlocal.bad"}}},
-    #             },
-    #             instance=instance,
-    #         )
-    #         list(event_stream)
-    # assert "Must use S3 or GCS storage with non-local Celery" in str(exc_info.value)
-
-
 def test_engine_error():
-    with pytest.raises(DagsterSubprocessError):
-        with seven.TemporaryDirectory() as tempdir:
-            with instance_for_test_tempdir(tempdir) as instance:
-                storage = os.path.join(tempdir, "flakey_storage")
-                execute_pipeline(
-                    ReconstructablePipeline.for_file(REPO_FILE, "engine_error"),
-                    run_config={
-                        "storage": {"filesystem": {"config": {"base_dir": storage}}},
-                        "execution": {
-                            "celery": {"config": {"config_source": {"task_always_eager": True}}}
+    with mock.patch(
+        "dagster.core.execution.context.system.SystemExecutionContextData.raise_on_error",
+        return_value=True,
+    ):
+        with pytest.raises(DagsterSubprocessError):
+            with tempfile.TemporaryDirectory() as tempdir:
+                with instance_for_test_tempdir(tempdir) as instance:
+                    storage = os.path.join(tempdir, "flakey_storage")
+                    execute_pipeline(
+                        ReconstructablePipeline.for_file(REPO_FILE, "engine_error"),
+                        run_config={
+                            "intermediate_storage": {
+                                "filesystem": {"config": {"base_dir": storage}}
+                            },
+                            "execution": {
+                                "celery": {"config": {"config_source": {"task_always_eager": True}}}
+                            },
+                            "solids": {"destroy": {"config": storage}},
                         },
-                        "solids": {"destroy": {"config": storage}},
-                    },
-                    instance=instance,
-                )
+                        instance=instance,
+                    )
